@@ -2,19 +2,17 @@
 # -*- coding: utf-8 -*-
 
 # all names not starting with under score must be a subcommand module.
-import jsonstream as json
+import jsonstream as jsons
 import tsv
 import io
 # import util
 import graph
 import dbi
-
-import cli as _cli
-
-_modules=dict([ (k,v) for k,v in locals().items() if not k.startswith('_') ])
+import panya
 
 def _main():
-    _cli.main(_modules)
+    
+    panya.panya.register()
+
+    panya.panya.baker.run()
 
-if __name__=='__main__':
-    _main()
